<?php
/**
 * getLaw WP API Client
 *
 * Plugin Name: getLaw WP API Client
 * Description: With this Plugin you can automatically embed legal texts of the Legal-Tech-Platform <a href="https://www.getLaw.de" target="_blank" rel="noopener">www.getLaw.de</a> in your website and your shop. A detailed instruction for setup you'll find at <a href="https://www.getlaw.de/api/wordpress/" target="_blank" rel="noopener">https://www.getlaw.de/api/wordpress/</a>.
 * Version:     1.0.6
 * Author:      getLaw.de
 * Author URI:  https://www.getlaw.de
 * License:     GPLv3 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: getlaw-wp-api-client
 * Domain Path: /languages
 * Requires at least: 4.6
 * Requires PHP: 5.6
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Silence is golden.
}

class GetLaw
{
	public static function get_text( $key, $manual_update = false )
	{
		$cached = get_option( 'getlaw_text_cache' );
		if ( empty( $cached[ $key ] ) || ( ! $manual_update && time() >= $cached[ $key ][ 'next_update' ] ) ) {
			$new_text = self::renew_text( $key );
			if ( empty( $new_text ) ) {
				return isset( $cached[ $key ][ 'content' ] ) ? $cached[ $key ][ 'content' ] : '';
			}
			return $new_text;
		}
		return $cached[ $key ][ 'content' ];
	}

	public static function renew_text( $key )
	{
		try {
                    $handle = curl_init();
                    curl_setopt($handle,CURLOPT_URL,'https://www.getlaw.de/api/texts/' . $key);
                    curl_setopt($handle,CURLOPT_HTTPHEADER,array('X-getLaw-API-Version: 1'));
                    curl_setopt($handle,CURLOPT_RETURNTRANSFER,true);
                    curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, 0);
                    curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, 0);
                    
                    $response = curl_exec($handle);
                    curl_close($handle);
                    
		} catch ( Exception $e ) {
			return '';
		}
		$data = json_decode( $response, true );
		if ( $data === null || $data[ 'error' ] ) {
			return '';
		}
		$new_cache = [ $key => [ 'next_update' => time() + 86400, 'content' => $data[ 'content' ] ] ];
		$old_cache = get_option( 'getlaw_text_cache' );
		if ( is_array( $old_cache ) ) {
			$new_cache = array_replace( $old_cache, $new_cache );
		}
		update_option( 'getlaw_text_cache', $new_cache, false );
		return $data[ 'content' ];
	}

	public static function options_page()
	{
		$msg = '';
		$fetch_text = get_option('getlaw_fetch_text_manually');
		if ( ! empty( $fetch_text ) ) {
			$key = '';
			switch ( $fetch_text ) {
				case 'impressum':
					$key = (string) get_option( 'getlaw_imprint_key' );
					break;
				case 'datenschutz':
					$key = (string) get_option( 'getlaw_privacy_key' );
					break;
				case 'agb':
					$key = (string) get_option( 'getlaw_terms_key' );
					break;
				case 'widerruf':
					$key = (string) get_option( 'getlaw_cancellation_policy_key' );
					break;
				default:
					break;
			}
			$new_text = self::renew_text( $key );
			if ( empty( $new_text ) ) {
				$msg .= __( 'Failed to update the text. Did you set the correct API key?', 'getlaw-wp-api-client' );
			} else {
				$msg .= __( 'Successfully updated text!', 'getlaw-wp-api-client' );
			}
			delete_option('getlaw_fetch_text_manually');
		}
                if  (!empty($msg)) {
                        echo '<div class="notice notice-error is-dismissible" role="alert"><p>' .  esc_html($msg) . '</p></div>'; 
                    }
?>
        <div class="wrap">
            <h1><?php esc_html_e( 'Settings › getLaw-WordPress-API', 'getlaw-wp-api-client' ); ?></h1>
            <p><?php _e( 'With this Plugin you can automatically embed legal texts of the Legal-Tech-Platform <a href="https://www.getLaw.de" target="_blank" rel="noopener">www.getLaw.de</a> in your website and your shop. A detailed instruction for setup you\'ll find at <a href="https://www.getlaw.de/api/wordpress/" target="_blank" rel="noopener">https://www.getlaw.de/api/wordpress/</a>.', 'getlaw-wp-api-client' ); ?></p>
            <form method="post" action="<?php echo esc_url ( admin_url( 'options.php' ) ); ?>" class="form-getlaw">
				<?php settings_fields( 'getlaw-wp-api-client' ); ?>
                <hr>
                <h2><?php esc_html_e( 'Imprint', 'getlaw-wp-api-client' ); ?></h2>
                <label for="getlaw_imprint_key"><?php esc_html_e('API key', 'getlaw-wp-api-client'); ?></label><br>
                <input type="text" name="getlaw_imprint_key" id="getlaw_imprint_key"
                       value="<?php echo esc_attr( get_option( 'getlaw_imprint_key' ) ); ?>"><br><br>
                <label for="getlaw_imprint_shortcode">Shortcode</label><br>
                <input type="text" id="getlaw_imprint_shortcode" readonly value="[getlaw text='impressum']">
                <label class="checkbox"><input type="checkbox" name="getlaw_imprint_manual_update"
                                               id="getlaw_imprint_manual_update"
                                               value="1" <?php echo( esc_attr( get_option(  'getlaw_imprint_manual_update' ) ? 'checked' : '' ) ) ?>><?php esc_html_e( 'Disable automatic fetching', 'getlaw-wp-api-client' ); ?>
                </label><br><br>
                <button type="submit" name="getlaw_fetch_text_manually" value="impressum"
                        class="button button-primary button-getlaw"><?php esc_html_e( 'Fetch text manually', 'getlaw-wp-api-client' ); ?></button>
                <hr>
                <h2><?php esc_html_e( 'Privacy policy', 'getlaw-wp-api-client' ); ?></h2>
                <label for="getlaw_privacy_key"><?php esc_html_e('API key', 'getlaw-wp-api-client'); ?></label><br>
                <input type="text" name="getlaw_privacy_key" id="getlaw_privacy_key"
                       value="<?php echo esc_attr( get_option( 'getlaw_privacy_key' ) ); ?>"><br><br>
                <label for="getlaw_privacy_shortcode">Shortcode</label><br>
                <input type="text" id="getlaw_privacy_shortcode" readonly value="[getlaw text='datenschutz']">
                <label class="checkbox"><input type="checkbox" name="getlaw_privacy_manual_update"
                                               id="getlaw_privacy_manual_update"
                                               value="1" <?php echo (  esc_attr( get_option( 'getlaw_privacy_manual_update' ) ? 'checked' : '' ) ) ?>><?php esc_html_e( 'Disable automatic fetching', 'getlaw-wp-api-client' ); ?>
                </label><br><br>
                <button type="submit" name="getlaw_fetch_text_manually" value="datenschutz"
                        class="button button-primary"><?php esc_html_e( 'Fetch text manually', 'getlaw-wp-api-client' ); ?></button>
                <hr>
                <h2><?php esc_html_e( 'Terms of Service', 'getlaw-wp-api-client' ); ?></h2>
                <label for="getlaw_terms_key"><?php esc_html_e('API key', 'getlaw-wp-api-client'); ?></label><br>
                <input type="text" name="getlaw_terms_key" id="getlaw_terms_key"
                       value="<?php echo esc_attr( get_option( 'getlaw_terms_key' ) ); ?>"><br><br>
                <label for="getlaw_terms_shortcode">Shortcode</label><br>
                <input type="text" id="getlaw_terms_shortcode" readonly value="[getlaw text='agb']">
                <label class="checkbox"><input type="checkbox" name="getlaw_terms_manual_update"
                                               id="getlaw_terms_manual_update"
                                               value="1" <?php echo( esc_attr( get_option(  'getlaw_terms_manual_update' ) ? 'checked' : '' ) ) ?>><?php esc_html_e( 'Disable automatic fetching', 'getlaw-wp-api-client' ); ?>
                </label><br><br>
                <button type="submit" name="getlaw_fetch_text_manually" value="agb"
                        class="button button-primary"><?php esc_html_e( 'Fetch text manually', 'getlaw-wp-api-client' ); ?></button>
                <hr>
                <h2><?php esc_html_e( 'Cancellation policy', 'getlaw-wp-api-client' ); ?></h2>
                <label for="getlaw_cancellation_policy_key"><?php esc_html_e('API key', 'getlaw-wp-api-client'); ?></label><br>
                <input type="text" name="getlaw_cancellation_policy_key" id="getlaw_cancellation_policy_key"
                       value="<?php echo esc_attr( get_option( 'getlaw_cancellation_policy_key' ) ); ?>"><br><br>
                <label for="getlaw_cancellation_policy_shortcode">Shortcode</label><br>
                <input type="text" id="getlaw_cancellation_policy_shortcode" readonly value="[getlaw text='widerruf']">
                <label class="checkbox"><input type="checkbox" name="getlaw_cancellation_policy_manual_update"
                                               id="getlaw_cancellation_policy_manual_update"
                                               value="1" <?php echo( esc_attr( get_option( 'getlaw_cancellation_policy_manual_update' ) ? 'checked' : '' ) ) ?>><?php esc_html_e( 'Disable automatic fetching', 'getlaw-wp-api-client' ); ?>
                </label><br><br>
                <button type="submit" name="getlaw_fetch_text_manually" value="widerruf"
                        class="button button-primary"><?php esc_html_e( 'Fetch text manually', 'getlaw-wp-api-client' ); ?></button>
				<?php submit_button(); ?>
            </form>
        </div>
<?php
	}

	public static function shortcode_output( $atts )
	{
		$msg = '';
		if ( empty( $atts[ 'text' ] ) || ! in_array( $atts[ 'text' ], [ 'impressum', 'datenschutz', 'agb', 'widerruf' ] ) ) {
			$msg .= esc_html__( 'Oops, you didn\'t configure the shortcode correctly. The correct shortcode would look like this: [getlaw text="TYPE_HERE"]. TYPE_HERE can be impressum for imprint, datenschutz for privacy policy, agb for terms of service or widerruf for cancellation policy.', 'getlaw-wp-api-client' );
		} else {
			$key = '';
			$manual_update = false;
			switch ( $atts[ 'text' ] ) {
				case 'impressum':
					$key = (string) get_option( 'getlaw_imprint_key' );
					$manual_update = (bool) get_option( 'getlaw_imprint_manual_update' );
					break;
				case 'datenschutz':
					$key = (string) get_option( 'getlaw_privacy_key' );
					$manual_update = (bool) get_option( 'getlaw_privacy_manual_update' );
					break;
				case 'agb':
					$key = (string) get_option( 'getlaw_terms_key' );
					$manual_update = (bool) get_option( 'getlaw_terms_manual_update' );
					break;
				case 'widerruf':
					$key = (string) get_option( 'getlaw_cancellation_policy_key' );
					$manual_update = (bool) get_option( 'getlaw_cancellation_policy_manual_update' );
					break;
				default:
					break;
			}
			$text = self::get_text( $key, $manual_update );
			if ( empty( $text ) ) {
				$msg .= esc_html__( 'Oops, we couldn\'t fetch the text. Please make sure you have configured the correct API key and your server is able to talk to www.getlaw.de.', 'getlaw-wp-api-client' );
			} else {
				$msg .= $text;
			}
		}
		return $msg;
	}

	public static function register_hooks()
	{
		add_action( 'plugins_loaded', function () {
			load_plugin_textdomain( 'getlaw-wp-api-client', FALSE, basename( __DIR__ ) . '/languages/' );
		} );

		add_filter( 'plugin_action_links', function ( $links, $file ) {
			if ( $file === 'getlaw-wp-api-client/getlaw-wp-api-client.php' && current_user_can( 'manage_options' ) ) {
				$links = (array) $links;
				$links[] = sprintf( '<a href="%s">%s</a>', esc_url ( admin_url( 'options-general.php?page=getlaw-wp-api-client' ) ), esc_html__( 'Settings', 'getlaw-wp-api-client' ) );
			}
			return $links;
		}, 10, 2 );

		add_action( 'admin_init', function () {
			register_setting( 'getlaw-wp-api-client ', 'getlaw_imprint_key', [ 'type' => 'string' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_privacy_key', [ 'type' => 'string' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_terms_key', [ 'type' => 'string' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_cancellation_policy_key', [ 'type' => 'string' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_imprint_manual_update', [ 'type' => 'boolean' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_privacy_manual_update', [ 'type' => 'boolean' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_terms_manual_update', [ 'type' => 'boolean' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_cancellation_policy_manual_update', [ 'type' => 'boolean' ] );
			register_setting( 'getlaw-wp-api-client ', 'getlaw_fetch_text_manually', [ 'type' => 'string' ] );
		} );

		add_filter( 'allowed_options', function ( $allowed_options ) {
			$allowed_options[ 'getlaw-wp-api-client' ] = [
				'getlaw_imprint_key',
				'getlaw_privacy_key',
				'getlaw_terms_key',
				'getlaw_cancellation_policy_key',
				'getlaw_imprint_manual_update',
				'getlaw_privacy_manual_update',
				'getlaw_terms_manual_update',
				'getlaw_cancellation_policy_manual_update',
				'getlaw_fetch_text_manually',
			];
			return $allowed_options;
		} );

		add_action( 'admin_menu', function () {
			add_options_page( __( 'getLaw-WordPress-API', 'getlaw-wp-api-client' ), __( 'getLaw-WordPress-API', 'getlaw-wp-api-client' ), 'manage_options', 'getlaw-wp-api-client', [ __CLASS__, 'options_page' ] );
		} );

		add_action( 'admin_enqueue_scripts', function () {
			if ( current_user_can( 'manage_options' ) && get_current_screen()->id === 'settings_page_getlaw-wp-api-client' ) {
				?>
                <style>
                    .form-getlaw .button.button-primary {
                        background-color: #303C53;
                        color: #FFFFFF;
                        font-size: 1rem;
                        border: 0;
                        padding: 0.32em 1.25em;
                        transition: .2s;
                        position: relative;
                    }

                    .form-getlaw .button.button-primary:hover {
                        background-color: #3d4d6b;
                        color: #CCCCCC;
                        box-shadow: 1px 2px 3px rgba(0, 0, 0, .15);
                    }

                    .form-getlaw .button.button-primary:focus,
                    .form-getlaw .button.button-primary:active {
                        top: 2px;
                    }

                    .form-getlaw input[name*="key"] {
                        width: 98%;
                        /*max-width: 640px;*/
                        height: 44px;
                    }

                    .form-getlaw input[id*="shortcode"] {
                        width: 98%;
                        max-width: 320px;
                        height: 44px;
                    }

                    .form-getlaw hr {
                        margin: 2em 0;
                    }

                    .form-getlaw label {
                        display: inline-block;
                        margin-bottom: 4px;
                        font-size: 14px;
                    }

                    .form-getlaw input.readonly,
                    .form-getlaw input[readonly],
                    .form-getlaw textarea.readonly,
                    .form-getlaw textarea[readonly] {
                        background-color: #d5d6d8;
                        font-weight: bold;
                    }

                    .form-getlaw p.submit {
                        width: 98%;
                        max-width: 640px;
                        text-align: right;
                    }

                    .form-getlaw .checkbox {
                        width: 98%;
                        max-width: 320px;
                        text-align: center;
                        margin-bottom: 0;
                    }

                    @media all and (max-width: 670px) {
                        .form-getlaw .checkbox {
                            text-align: left;
                            margin: 30px 0 8px 0;
                        }
                    }
                </style>
<?php
			}
		} );

		add_shortcode( 'getlaw', [ __CLASS__, 'shortcode_output' ] );
	}
}

GetLaw::register_hooks();
